class CustomList(list):
    def __init__(self, _list):
        for i, val in enumerate(_list):
            if isinstance(val, list):
                _list[i] = CustomList(val)
            elif isinstance(val, dict):
                _list[i] = CustomDict(val)

        list.__init__(self, _list)

class CustomDict(dict):
    def __init__(self, _dict):
        dict.__init__(self, _dict)

        for key in list(_dict):
            if isinstance(_dict[key], list):
                dict.__setitem__(self, key, CustomList(_dict[key]))
            elif isinstance(_dict[key], dict):
                dict.__setitem__(self, key, CustomDict(_dict[key]))
            else:
                dict.__setitem__(self, key, _dict[key])

    def __getattr__(self, name):  # CustomDict.a
        return dict.__getitem__(self, name)

    def __setattr__(self, name, value):  # CustomDict.a = 'something'
        return dict.__setitem__(self, name, value)

    def __delattr__(self, name):  # del CustomDict.a
        popped = dict.__getitem__(key)
        dict.__delitem__(self, key)
        return popped



from .CustomTypes import CustomList, CustomDict
import json

def objectify(data):
    if isinstance(data, list):
        return CustomList(data)
    elif isinstance(data, dict):
        return CustomDict(data)
    else:
        return data

def loads(data, cls=None, object_hook=None, parse_float=None, parse_int=None, parse_constant=None, object_pairs_hook=None):
    _data = json.loads(
        data, cls=cls, object_hook=object_hook, parse_float=parse_float, parse_int=parse_int,
        parse_constant=parse_constant, object_pairs_hook=object_pairs_hook
    )

    return objectify(_data)

def load(io, cls=None, object_hook=None, parse_float=None, parse_int=None, parse_constant=None, object_pairs_hook=None):
    _data = json.load(io, cls=cls, object_hook=object_hook, parse_float=parse_float, parse_int=parse_int,
    parse_constant=parse_constant, object_pairs_hook=object_pairs_hook)

    return objectify(_data)

def dumps(data, skipkeys=False, ensure_ascii=True, check_circular=True, allow_nan=True, cls=None, indent=None,
          separators=None, default=None, sort_keys=False):
    return json.dumps(data, skipkeys=skipkeys, ensure_ascii=ensure_ascii, check_circular=check_circular,
                      allow_nan=allow_nan, cls=cls, indent=indent, separators=separators, default=default,
                      sort_keys=sort_keys
    )

def dump(data, io, skipkeys=False, ensure_ascii=True, check_circular=True, allow_nan=True, cls=None, indent=None,
         separators=None, default=None, sort_keys=False):
    return json.dump(data, io, skipkeys=skipkeys, ensure_ascii=ensure_ascii, check_circular=check_circular,
                     allow_nan=allow_nan, cls=cls, indent=indent, separators=separators, default=default,
                     sort_keys=sort_keys
    )



import setuptools

with open('README.md', 'r') as fh:
    long_description = fh.read()

setuptools.setup(
    name='classy-json',
    version='1.3.0',
    author='Iapetus-11',
    description='An attempt to recreate the way json behaves in Javascript, but in Python',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/Iapetus-11/Classy-Json',
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6'
)
